@@ -185,8 +185,7 @@ right.labs <- function(beta, iname, cex.names, coef.col) # varnames on right of
 {
     usr <- par("usr")
     text(x=usr[2] + .01 * (usr[2] - usr[1]),
-         y=TeachingDemos::spread.labs(beta[iname, ncol(beta)],
-                                      mindiff=1.2 * cex.names * strheight("X")),
+         y=spread.labs(beta[iname, ncol(beta)], mindiff=1.2 * cex.names * strheight("X")),
          labels=names(iname), cex=cex.names, col=coef.col[iname], adj=0, xpd=NA)
 }
 top.axis <- function(obj, x, nresponse, approx.f)
@@ -257,7 +256,7 @@ add.s.line <- function(lambda, x, beta, s, grid.col, coef.col, s.col, ...)
             force.col=s.col, force.cex=.8, def.srt=90, def.xpd=NA, ...)
 }
 # Return NULL or an integer vector
-# Reproduced here (from glmnet version 2.0-5, march 2016)
+# Reproduced here (from glmnet version 2.0-16, nov 2018)
 # so don't have to import glmnet into plotmo.
 
 nonzeroCoef = function (beta, bystep = FALSE)
